@@ -13,54 +13,51 @@ from ...consts import SERVICE_CODE
 import traceback
 
 
-api = Blueprint('api', __name__, url_prefix='/api/v2')
-__version__ = '2.0'
+api = Blueprint("api", __name__, url_prefix="/api/v2")
+__version__ = "2.0"
 
 
 @api.errorhandler(401)
 def unauthorized_error(e):
     return unauthorized(
-        service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-Id')
-        )
+        service_code=SERVICE_CODE, request_id=request.headers.get("X-Request-Id")
+    )
 
 
 @api.errorhandler(403)
 def forbidden_error(e):
     return forbidden(
-        service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-Id')
-        )
+        service_code=SERVICE_CODE, request_id=request.headers.get("X-Request-Id")
+    )
 
 
 @api.errorhandler(404)
 def not_found_error(e):
     return not_found(
-        service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-Id')
-        )
+        service_code=SERVICE_CODE, request_id=request.headers.get("X-Request-Id")
+    )
 
 
 @api.errorhandler(405)
 def method_not_allowed_error(e):
     return not_allowed(
-        service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-Id')
-        )
+        service_code=SERVICE_CODE, request_id=request.headers.get("X-Request-Id")
+    )
 
 
 @api.errorhandler(500)
 def internal_server_error(e):
     message = {
-        'error': str(e),
-        'traceback': ''.join(traceback.format_tb(e.__traceback__))
-        }
+        "error": str(e),
+        "traceback": "".join(traceback.format_tb(e.__traceback__)),
+    }
     return internal_error(
         message,
         service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-Id')
-        )
+        request_id=request.headers.get("X-Request-Id"),
+    )
 
-from . import apps, auth, departments, positions, users  # NOQA
+
+from . import apps, auth, departments, positions, users, odoo  # NOQA
 
 # EOF
